#!/usr/bin/env python2.3
# -*- coding: utf-8 -*-

import pygame
from pygame.locals import *

import os, sys, getopt

from game import Game

DEFAULT_HOST = "localhost"
DEFAULT_PORT = 8001

def usage():
    """
    Imprime informações de uso deste programa.
    """
    prog = sys.argv[ 0 ]
    print "Usage:"
    print ( "\t%s [-f|--fullscreen] [-s|--server=<host>[:<port>]] " \
            "[-c|--client=<url>] [-r <XxY>|--resolution=<XxY>]" ) % prog
    print
# usage()



def parse_opts( argv ):
    """
    Pega as informações da linha de comando e retorna 
    """
    # Analise a linha de commando usando 'getopt'
    try:
        opts, args = getopt.gnu_getopt( argv[ 1 : ],
                                        "hfs:c:r:",
                                        [ "help",
                                          "fullscreen",
                                          "server=",
                                          "client=",
                                          "resolution=" ] )
    except getopt.GetoptError:
        # imprime informacao e sai
        usage()
        sys.exit( 2 )

    options = {
        "fullscreen": False,
        "server":     None,
        "client":     None,
        "resolution": ( 800, 600 ),
        }

    for o, a in opts:
        if o in ( "-f", "--fullscreen" ):
            options[ "fullscreen" ] = True
        elif o in ( "-h", "--help" ):
            usage()
            sys.exit( 0 )
        elif o in ( "-s", "--server" ):
            options[ "server" ] = [ DEFAULT_HOST, DEFAULT_PORT ]
            if a:
                s = a.split( ":" )
                if len( s ) == 2:
                    options[ "server" ] = ( s[ 0 ], int( s[ 1 ] ) )
                else:
                    options[ "server" ][ 0 ] = s[ 0 ]
        elif o in ( "-c", "--client" ):
            if a:
                options[ "client" ] = a
            else:
                options[ "client" ] = "http://%s:%d" % ( DEFAULT_HOST,
                                                         DEFAULT_PORT )
        elif o in ( "-r", "--resolution" ):
            a = a.lower()
            r = a.split( "x" )
            if len( r ) == 2:
                options[ "resolution" ] = r
                continue

            r = a.split( "," )
            if len( r ) == 2:
                options[ "resolution" ] = r
                continue

            r = a.split( ":" )
            if len( r ) == 2:
                options[ "resolution" ] = r
                continue
    # for o, a in opts
    r = options[ "resolution" ]
    options[ "resolution" ] = [ int( r[ 0 ] ), int( r[ 1 ] ) ]
    return options
# parse_opts()



def main( argv ):
    #primeiro vamos verificar que estamos no diretorio certo para conseguir
    #encontrar as imagens e outros recursos, e inicializar o pygame com as
    #opcoes passadas pela linha de comando
    fullpath = os.path.abspath( argv[ 0 ] )
    dir = os.path.dirname( fullpath )
    os.chdir( dir )

    options = parse_opts( argv )
    try:
        game = Game( options[ "resolution" ], options[ "fullscreen" ],
                     options[ "server" ], options[ "client" ] )
        game.loop()
    except Exception, e:
        print "Erro: %s" % e
# main()
        
# este comando fala para o python chamar o main se estao executando o script
if __name__ == '__main__':
    main( sys.argv )

